agentle.mcp.models.text\_resource\_contents
===========================================

.. automodule:: agentle.mcp.models.text_resource_contents

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      ResourceContents
      TextResourceContents
   